
#include <bool.h>
#include "Object.h"

#ifndef __Enumeration__
#define __Enumeration__

  /* 
   *  An object that implements the Enumeration interface generates a series of elements, one at a time. 
   *  Successive calls to the nextElement method return successive elements of the series. 
   *  
   *  For example, to print all elements of a vector v: 
   *  
   *  for (Enumeration e = v.elements() ; e.hasMoreElements() ;) 
   *  {
   *     cout<<(e.nextElement()).toString();
   *  }
   *  
   *  Methods are provided to enumerate through the elements of a vector, the keys of a hashtable, 
   *  and the values in a hashtable. 
   */

class Enumeration 
{
public:
  /** 
   * Tests if this enumeration contains more elements.
   */
  virtual bool hasMoreElements(){return false;};
  /** 
   * Returns the next element of this enumeration. 
   */
  virtual Object *nextElement(){return NULL;}; 
  /** 
   * Returns a String representing the Enumeration 
   */
  String toString();
};
#endif
